@@ -17,7 +17,7 @@ class BackupDirectory(BackupFile):
     maintain designated archive of copies on the remote server
     """
 
-    directories: tuple[str] = ()
+    directories: tuple[str, ...] = ()
 
     def process(self) -> None:
         """
