@@ -78,11 +78,11 @@ class ObjectStorageFile:
                 bucket_name=self.bucket,
                 delete_object_list=[DeleteObject(obj) for obj in objects],
             )
-            errors = 0
+            error_count = 0
             for error in resp:
-                errors += 1
+                error_count += 1
                 logger.info(f'Error deleting object: {error}')
-            errors = errors if errors else 'no'
+            errors = error_count if error_count else 'no'
             logger.info(
                 f'Deleted {len(objects)} files from {self.bucket}/{self.prefix} with {errors} errors'
             )
