@@ -1,6 +1,7 @@
 from lcconfig.configparser import ConsoleSettingsConfig
 from getpass import getpass
 from invoke import task, Context
+from pathlib import Path
 from capsule import settings
 from capsule.typehints import KeyringService
 from capsule.wizards import persist_object_storage_config
@@ -15,6 +16,10 @@ def setup(ctx: Context) -> None:
     if settings.IS_DRAWBRIDGE_OS:
         print('Is a Drawbridge system. Not overwriting existing System config and Email config.')
         return
+
+    if settings.IS_GENERAL_SERVER:
+        Path('/etc/compass').mkdir(exist_ok=True)
+
     ConsoleKeyring.generate_new_key()
     setup_object_storage_server()
     setup_boxdata()
