@@ -2,25 +2,31 @@ from invoke import Context, task
 
 from ..backups import BackupEtc
 from ..downloader import downloader
+from ..settings import DIRECTORY_LAST_BACKUP_TIME
 from ..typehints import INTERVALS
+from ..utils.zabbix import record_successful_backup_time
 
 
 @task
-def backup(ctx: Context) -> None:
+def backup(ctx: Context) -> bool:
     """
-    Backup all contents of the /etc directory.
+    Backup needed files from the /etc directory.
     """
-    print(f'Backing up {BackupEtc.directory}... ', end='', flush=True)
+    print('Backing up subsdirectories in /etc... ', end='', flush=True)
     BackupEtc(ctx, filename='etc.tbz2').process()
     print('Done')
 
+    record_successful_backup_time(DIRECTORY_LAST_BACKUP_TIME)
+
+    return True
+
 
 @task(
     help={
         'interval': 'File archive interval - (daily, weekly, monthly)',
     },
 )
-def backup_files(ctx: Context, interval: INTERVALS = '') -> None:
+def backup_files(ctx: Context, interval: INTERVALS = '') -> bool:
     """
     Show all Etc backup files for specified interval.
     """
@@ -32,6 +38,8 @@ def backup_files(ctx: Context, interval: INTERVALS = '') -> None:
             print(bf)
         print()
 
+    return True
+
 
 @task(
     help={
@@ -39,11 +47,12 @@ def backup_files(ctx: Context, interval: INTERVALS = '') -> None:
         'filename': 'Remote backup filename to download',
     },
 )
-def download(ctx: Context, interval: INTERVALS, filename: str) -> None:
+def download(ctx: Context, interval: INTERVALS, filename: str) -> bool:
     """
     Download specified Etc backup tarball from the backup server.
     """
     downloader(interval, filename, BackupEtc.base_prefix)
+    return True
 
 
 __all__ = (
