@@ -9,9 +9,9 @@ else:
 
 
 def create_tarball(
-    source_dirs: tuple[str],
+    source_dirs: tuple[str, ...],
     destination: str,
-    exclude_patterns: tuple[str],
+    exclude_patterns: tuple[str, ...],
 ):
     """
     Creates a compressed archive of a directory, excluding files matching specified patterns.
